@@ -2,26 +2,26 @@
 -- Update Database Script
 -- *********************************************************************
 -- Change Log: upgrade.changelog-up-to-6.0.0.xml
--- Ran at: 03/12/2025 17:50
+-- Ran at: 08/01/2026 11:50
 -- Against: squashtm@jdbc:postgresql://postgres/squashtest
 -- Liquibase version: 4.19.0
 -- *********************************************************************
 
 -- Lock Database
-UPDATE databasechangeloglock SET LOCKED = TRUE, LOCKEDBY = 'runner-yfpexrfv8-project-33554404-concurrent-0-ltb56xtz (100.64.9.58)', LOCKGRANTED = NOW() WHERE ID = 1 AND LOCKED = FALSE;
+UPDATE databasechangeloglock SET LOCKED = TRUE, LOCKEDBY = 'runner-yfpexrfv8-project-33554404-concurrent-0-d19jc3z5 (100.64.14.156)', LOCKGRANTED = NOW() WHERE ID = 1 AND LOCKED = FALSE;
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0::lmurat
 -- Update TM database version number
 UPDATE CORE_CONFIG SET VALUE = '6.0.0' WHERE STR_KEY = 'squashtest.tm.database.version';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0', 'lmurat', '../tm/tm.changelog-6.0.0.xml', NOW(), 1, '8:58f17ae7fc8eee68e0b45d9a115f3784', 'update tableName=CORE_CONFIG', 'Update TM database version number', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0', 'lmurat', '../tm/tm.changelog-6.0.0.xml', NOW(), 1, '8:58f17ae7fc8eee68e0b45d9a115f3784', 'update tableName=CORE_CONFIG', 'Update TM database version number', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-SQUASH-6260-cleanup-core-party-authority-table::lmurat
 -- Remove ROLE_TM_USER from CORE_PARTY_AUTHORITY
 DELETE FROM CORE_PARTY_AUTHORITY
     WHERE AUTHORITY = 'ROLE_TM_USER';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-SQUASH-6260-cleanup-core-party-authority-table', 'lmurat', '../tm/tm.changelog-6.0.0.xml', NOW(), 2, '8:e9c6db4305989db996f20fbc3f141c15', 'sql', 'Remove ROLE_TM_USER from CORE_PARTY_AUTHORITY', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-SQUASH-6260-cleanup-core-party-authority-table', 'lmurat', '../tm/tm.changelog-6.0.0.xml', NOW(), 2, '8:e9c6db4305989db996f20fbc3f141c15', 'sql', 'Remove ROLE_TM_USER from CORE_PARTY_AUTHORITY', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-SQUASH-6284-login-up-to-100-characters::mbrugniere
 -- Update login maxlength for all tables concerned (from 50 to 100)
@@ -163,7 +163,7 @@ ALTER TABLE TEST_SUITE ALTER COLUMN LAST_MODIFIED_BY TYPE VARCHAR(100) USING (LA
 
 ALTER TABLE TEST_SUITE ALTER COLUMN  CREATED_BY SET NOT NULL;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-SQUASH-6284-login-up-to-100-characters', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 3, '8:aa6203fbbef514e97eabeed812f50af1', 'modifyDataType columnName=CREATED_BY, tableName=ACTION_WORD; addNotNullConstraint columnName=CREATED_BY, tableName=ACTION_WORD; modifyDataType columnName=LAST_MODIFIED_BY, tableName=ACTION_WORD; modifyDataType columnName=LOGIN, tableName=AUTH_USER...', 'Update login maxlength for all tables concerned (from 50 to 100)', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-SQUASH-6284-login-up-to-100-characters', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 3, '8:aa6203fbbef514e97eabeed812f50af1', 'modifyDataType columnName=CREATED_BY, tableName=ACTION_WORD; addNotNullConstraint columnName=CREATED_BY, tableName=ACTION_WORD; modifyDataType columnName=LAST_MODIFIED_BY, tableName=ACTION_WORD; modifyDataType columnName=LOGIN, tableName=AUTH_USER...', 'Update login maxlength for all tables concerned (from 50 to 100)', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-create-exploratory-test-case::pckerneis
 -- Create the exploratory test case table
@@ -175,7 +175,7 @@ COMMENT ON COLUMN EXPLORATORY_TEST_CASE.CHARTER IS 'the charter for an explorato
 
 COMMENT ON COLUMN EXPLORATORY_TEST_CASE.SESSION_DURATION IS 'the test session planned duration in minutes';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-test-case', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 4, '8:d6da1d9d969d794b17ee935215a2fe51', 'createTable tableName=EXPLORATORY_TEST_CASE', 'Create the exploratory test case table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-test-case', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 4, '8:d6da1d9d969d794b17ee935215a2fe51', 'createTable tableName=EXPLORATORY_TEST_CASE', 'Create the exploratory test case table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-create-exploratory-execution::pckerneis
 -- Create the exploratory execution table
@@ -185,11 +185,11 @@ COMMENT ON COLUMN EXPLORATORY_EXECUTION.EXECUTION_ID IS 'primary key shared with
 
 CREATE INDEX idx_fk_exploratory_execution_assignee ON EXPLORATORY_EXECUTION(ASSIGNEE_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-execution', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 5, '8:2fdd0cc5a94cb40c2062cc8582d3af5c', 'createTable tableName=EXPLORATORY_EXECUTION; createIndex indexName=idx_fk_exploratory_execution_assignee, tableName=EXPLORATORY_EXECUTION', 'Create the exploratory execution table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-execution', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 5, '8:2fdd0cc5a94cb40c2062cc8582d3af5c', 'createTable tableName=EXPLORATORY_EXECUTION; createIndex indexName=idx_fk_exploratory_execution_assignee, tableName=EXPLORATORY_EXECUTION', 'Create the exploratory execution table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-create-session-note-for-exploratory-execution::mbrugniere
 -- Create the session note table
-CREATE TABLE SESSION_NOTE (NOTE_ID BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL, EXECUTION_ID BIGINT NOT NULL, KIND VARCHAR(30) DEFAULT 'COMMENT' NOT NULL, CONTENT TEXT DEFAULT '' NOT NULL, CREATED_BY VARCHAR(100) NOT NULL, CREATED_ON TIMESTAMP WITHOUT TIME ZONE NOT NULL, LAST_MODIFIED_BY VARCHAR(100) DEFAULT null, LAST_MODIFIED_ON TIMESTAMP WITHOUT TIME ZONE DEFAULT null, ATTACHMENT_LIST_ID BIGINT, ISSUE_LIST_ID BIGINT, NOTE_ORDER INTEGER, CONSTRAINT pk_session_note PRIMARY KEY (NOTE_ID), CONSTRAINT fk_session_note_execution FOREIGN KEY (EXECUTION_ID) REFERENCES EXECUTION(EXECUTION_ID), CONSTRAINT fk_session_note_issue_list FOREIGN KEY (ISSUE_LIST_ID) REFERENCES ISSUE_LIST(ISSUE_LIST_ID), CONSTRAINT fk_session_note_attachment_list FOREIGN KEY (ATTACHMENT_LIST_ID) REFERENCES ATTACHMENT_LIST(ATTACHMENT_LIST_ID));
+CREATE TABLE SESSION_NOTE (NOTE_ID BIGINT GENERATED BY DEFAULT AS IDENTITY NOT NULL, EXECUTION_ID BIGINT NOT NULL, KIND VARCHAR(30) DEFAULT 'COMMENT' NOT NULL, CONTENT TEXT DEFAULT '' NOT NULL, CREATED_BY VARCHAR(100) NOT NULL, CREATED_ON TIMESTAMP WITHOUT TIME ZONE NOT NULL, LAST_MODIFIED_BY VARCHAR(100) DEFAULT null, LAST_MODIFIED_ON TIMESTAMP WITHOUT TIME ZONE DEFAULT null, ATTACHMENT_LIST_ID BIGINT, ISSUE_LIST_ID BIGINT, NOTE_ORDER INTEGER, CONSTRAINT pk_session_note PRIMARY KEY (NOTE_ID), CONSTRAINT fk_session_note_attachment_list FOREIGN KEY (ATTACHMENT_LIST_ID) REFERENCES ATTACHMENT_LIST(ATTACHMENT_LIST_ID), CONSTRAINT fk_session_note_execution FOREIGN KEY (EXECUTION_ID) REFERENCES EXECUTION(EXECUTION_ID), CONSTRAINT fk_session_note_issue_list FOREIGN KEY (ISSUE_LIST_ID) REFERENCES ISSUE_LIST(ISSUE_LIST_ID));
 
 COMMENT ON COLUMN SESSION_NOTE.NOTE_ID IS 'primary key for SESSION_NOTE';
 
@@ -211,19 +211,19 @@ CREATE INDEX idx_session_note_last_modified_by ON SESSION_NOTE(LAST_MODIFIED_BY)
 
 CREATE INDEX idx_fk_session_note_attachment_list ON SESSION_NOTE(ATTACHMENT_LIST_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-session-note-for-exploratory-execution', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 6, '8:5d4e3cbd2cd18de34195e9c16bc613b3', 'createTable tableName=SESSION_NOTE; createIndex indexName=idx_fk_session_note_execution, tableName=SESSION_NOTE; createIndex indexName=idx_fk_session_note_issue_list_id, tableName=SESSION_NOTE; createIndex indexName=idx_session_note_created_by, ta...', 'Create the session note table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-session-note-for-exploratory-execution', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 6, '8:5d4e3cbd2cd18de34195e9c16bc613b3', 'createTable tableName=SESSION_NOTE; createIndex indexName=idx_fk_session_note_execution, tableName=SESSION_NOTE; createIndex indexName=idx_fk_session_note_issue_list_id, tableName=SESSION_NOTE; createIndex indexName=idx_session_note_created_by, ta...', 'Create the session note table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-ISSUE-269-increase-max-size-for-test-reference::dclaerhout
 -- Increase max size for automated test reference in test case table
 ALTER TABLE TEST_CASE ALTER COLUMN AUTOMATED_TEST_REFERENCE TYPE VARCHAR(512) USING (AUTOMATED_TEST_REFERENCE::VARCHAR(512));
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-ISSUE-269-increase-max-size-for-test-reference', 'dclaerhout', '../tm/tm.changelog-6.0.0.xml', NOW(), 7, '8:a21dc7000c7d5844f60f7b8095bc3bfd', 'modifyDataType columnName=AUTOMATED_TEST_REFERENCE, tableName=TEST_CASE', 'Increase max size for automated test reference in test case table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-ISSUE-269-increase-max-size-for-test-reference', 'dclaerhout', '../tm/tm.changelog-6.0.0.xml', NOW(), 7, '8:a21dc7000c7d5844f60f7b8095bc3bfd', 'modifyDataType columnName=AUTOMATED_TEST_REFERENCE, tableName=TEST_CASE', 'Increase max size for automated test reference in test case table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-issue-368-add-additional-configuration-to-test-automation-server::fahadi
 -- Add additional configuration to the test automation server
 ALTER TABLE TEST_AUTOMATION_SERVER ADD ADDITIONAL_CONFIGURATION TEXT;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-issue-368-add-additional-configuration-to-test-automation-server', 'fahadi', '../tm/tm.changelog-6.0.0.xml', NOW(), 8, '8:ae13402136cbb1b79a45e90dec8a42b0', 'addColumn tableName=TEST_AUTOMATION_SERVER', 'Add additional configuration to the test automation server', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-issue-368-add-additional-configuration-to-test-automation-server', 'fahadi', '../tm/tm.changelog-6.0.0.xml', NOW(), 8, '8:ae13402136cbb1b79a45e90dec8a42b0', 'addColumn tableName=TEST_AUTOMATION_SERVER', 'Add additional configuration to the test automation server', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-update-execution_issues_closure::mbrugniere
 -- Consider session notes to get all known issues for an execution
@@ -242,7 +242,7 @@ CREATE VIEW EXECUTION_ISSUES_CLOSURE AS select exec.execution_id, issue.issue_id
       from SESSION_NOTE sn
              inner join ISSUE on ISSUE.issue_list_id = sn.issue_list_id;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-update-execution_issues_closure', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 9, '8:63142af44781509e4550973a244cc317', 'dropView viewName=EXECUTION_ISSUES_CLOSURE; createView viewName=EXECUTION_ISSUES_CLOSURE', 'Consider session notes to get all known issues for an execution', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-update-execution_issues_closure', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 9, '8:63142af44781509e4550973a244cc317', 'dropView viewName=EXECUTION_ISSUES_CLOSURE; createView viewName=EXECUTION_ISSUES_CLOSURE', 'Consider session notes to get all known issues for an execution', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-add-grid-column-display-reference-table::jmarque
 -- Create the grid reference table
@@ -258,7 +258,7 @@ CREATE INDEX idx_fk_grid_column_display_reference_party_id ON GRID_COLUMN_DISPLA
 
 CREATE INDEX idx_fk_grid_column_display_reference_project_id ON GRID_COLUMN_DISPLAY_REFERENCE(PROJECT_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-grid-column-display-reference-table', 'jmarque', '../tm/tm.changelog-6.0.0.xml', NOW(), 10, '8:e47ff361f4ee9d8fd94b75322b9692ba', 'createTable tableName=GRID_COLUMN_DISPLAY_REFERENCE; createIndex indexName=idx_fk_grid_column_display_reference_party_id, tableName=GRID_COLUMN_DISPLAY_REFERENCE; createIndex indexName=idx_fk_grid_column_display_reference_project_id, tableName=GRI...', 'Create the grid reference table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-grid-column-display-reference-table', 'jmarque', '../tm/tm.changelog-6.0.0.xml', NOW(), 10, '8:e47ff361f4ee9d8fd94b75322b9692ba', 'createTable tableName=GRID_COLUMN_DISPLAY_REFERENCE; createIndex indexName=idx_fk_grid_column_display_reference_party_id, tableName=GRID_COLUMN_DISPLAY_REFERENCE; createIndex indexName=idx_fk_grid_column_display_reference_project_id, tableName=GRI...', 'Create the grid reference table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-add-grid-column-display-configuration-table::jmarque
 -- Create the grid configuration table
@@ -270,7 +270,7 @@ COMMENT ON COLUMN GRID_COLUMN_DISPLAY_CONFIGURATION.GCDR_ID IS 'foreign key to G
 
 CREATE INDEX idx_fk_grid_column_display_configuration_gcdr_id ON GRID_COLUMN_DISPLAY_CONFIGURATION(GCDR_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-grid-column-display-configuration-table', 'jmarque', '../tm/tm.changelog-6.0.0.xml', NOW(), 11, '8:e95b4bb90b311b5f84648616241b6e5d', 'createTable tableName=GRID_COLUMN_DISPLAY_CONFIGURATION; createIndex indexName=idx_fk_grid_column_display_configuration_gcdr_id, tableName=GRID_COLUMN_DISPLAY_CONFIGURATION', 'Create the grid configuration table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-grid-column-display-configuration-table', 'jmarque', '../tm/tm.changelog-6.0.0.xml', NOW(), 11, '8:e95b4bb90b311b5f84648616241b6e5d', 'createTable tableName=GRID_COLUMN_DISPLAY_CONFIGURATION; createIndex indexName=idx_fk_grid_column_display_configuration_gcdr_id, tableName=GRID_COLUMN_DISPLAY_CONFIGURATION', 'Create the grid configuration table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-create-exploratory-execution-event-table::pckerneis
 -- Create the exploratory session event table
@@ -282,13 +282,13 @@ COMMENT ON COLUMN EXPLORATORY_EXECUTION_EVENT.EXECUTION_ID IS 'foreign key to EX
 
 ALTER TABLE EXPLORATORY_EXECUTION_EVENT ADD CONSTRAINT uc_exploratory_execution_event_execution_id_event_date UNIQUE (EXECUTION_ID, EVENT_DATE);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-execution-event-table', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 12, '8:3244ed07a4fbf493862937af300edcf9', 'createTable tableName=EXPLORATORY_EXECUTION_EVENT; addUniqueConstraint constraintName=uc_exploratory_execution_event_execution_id_event_date, tableName=EXPLORATORY_EXECUTION_EVENT', 'Create the exploratory session event table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-create-exploratory-execution-event-table', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 12, '8:3244ed07a4fbf493862937af300edcf9', 'createTable tableName=EXPLORATORY_EXECUTION_EVENT; addUniqueConstraint constraintName=uc_exploratory_execution_event_execution_id_event_date, tableName=EXPLORATORY_EXECUTION_EVENT', 'Create the exploratory session event table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-add-dataset-parameter-order::pckerneis
 -- add an order to parameters
 ALTER TABLE PARAMETER ADD PARAM_ORDER INTEGER;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-dataset-parameter-order', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 13, '8:4009792036fb3f54151827a230cca8cf', 'addColumn tableName=PARAMETER', 'add an order to parameters', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-dataset-parameter-order', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 13, '8:4009792036fb3f54151827a230cca8cf', 'addColumn tableName=PARAMETER', 'add an order to parameters', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-add-dataset-parameter-order-generation::pckerneis
 create table PARAM_TEMP (id bigint, cnt int);
@@ -306,7 +306,7 @@ drop table PARAM_TEMP;
 
 ALTER TABLE PARAMETER ALTER COLUMN PARAM_ORDER SET NOT NULL;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-dataset-parameter-order-generation', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 14, '8:dd7b1de9a3c8d43f21d333727891682d', 'sql', '', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-dataset-parameter-order-generation', 'pckerneis', '../tm/tm.changelog-6.0.0.xml', NOW(), 14, '8:dd7b1de9a3c8d43f21d333727891682d', 'sql', '', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-add-exploratory-session-overview::mbrugniere
 -- Create the exploratory session overview table
@@ -324,7 +324,7 @@ CREATE INDEX idx_fk_exploratory_session_overview_itpi ON EXPLORATORY_SESSION_OVE
 
 CREATE INDEX idx_fk_exploratory_session_overview_attachment_list ON EXPLORATORY_SESSION_OVERVIEW(ATTACHMENT_LIST_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-exploratory-session-overview', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 15, '8:ee55c8c1aa5423a03523dc4b5f506522', 'createTable tableName=EXPLORATORY_SESSION_OVERVIEW; createIndex indexName=idx_fk_exploratory_session_overview_itpi, tableName=EXPLORATORY_SESSION_OVERVIEW; createIndex indexName=idx_fk_exploratory_session_overview_attachment_list, tableName=EXPLOR...', 'Create the exploratory session overview table', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-add-exploratory-session-overview', 'mbrugniere', '../tm/tm.changelog-6.0.0.xml', NOW(), 15, '8:ee55c8c1aa5423a03523dc4b5f506522', 'createTable tableName=EXPLORATORY_SESSION_OVERVIEW; createIndex indexName=idx_fk_exploratory_session_overview_itpi, tableName=EXPLORATORY_SESSION_OVERVIEW; createIndex indexName=idx_fk_exploratory_session_overview_attachment_list, tableName=EXPLOR...', 'Create the exploratory session overview table', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-squash-remove-resultpublisher-plugin-binding::bms
 DELETE FROM LIBRARY_PLUGIN_BINDING_PROPERTY
@@ -335,12 +335,12 @@ DELETE FROM LIBRARY_PLUGIN_BINDING_PROPERTY
 
 DELETE FROM LIBRARY_PLUGIN_BINDING WHERE PLUGIN_ID = 'squash.tm.plugin.resultpublisher';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-squash-remove-resultpublisher-plugin-binding', 'bms', '../tm/tm.changelog-6.0.0.xml', NOW(), 16, '8:0b1332faad6e21410756b12d60f8ff92', 'sql', '', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-squash-remove-resultpublisher-plugin-binding', 'bms', '../tm/tm.changelog-6.0.0.xml', NOW(), 16, '8:0b1332faad6e21410756b12d60f8ff92', 'sql', '', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Changeset ../tm/tm.changelog-6.0.0.xml::tm-6.0.0-667-rename-squashautom-ta-server-kind::jprioux
 UPDATE TEST_AUTOMATION_SERVER SET KIND = 'squashOrchestrator' WHERE KIND = 'squashAutom';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-667-rename-squashautom-ta-server-kind', 'jprioux', '../tm/tm.changelog-6.0.0.xml', NOW(), 17, '8:a0980811d3c54a8db982dc315e878f94', 'update tableName=TEST_AUTOMATION_SERVER', '', 'EXECUTED', NULL, NULL, '4.19.0', '4780607230');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-6.0.0-667-rename-squashautom-ta-server-kind', 'jprioux', '../tm/tm.changelog-6.0.0.xml', NOW(), 17, '8:a0980811d3c54a8db982dc315e878f94', 'update tableName=TEST_AUTOMATION_SERVER', '', 'EXECUTED', NULL, NULL, '4.19.0', '7869450750');
 
 -- Release Database Lock
 UPDATE databasechangeloglock SET LOCKED = FALSE, LOCKEDBY = NULL, LOCKGRANTED = NULL WHERE ID = 1;
